Class: Google::Cloud::WorkloadManager::V1::Command

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workloadmanager/v1/service.rb

Overview

Command specifies the type of command to execute.

Instance Attribute Summary collapse

Instance Attribute Details

#agent_command::Google::Cloud::WorkloadManager::V1::AgentCommand

Returns AgentCommand specifies a one-time executable program for the agent to run.

Note: The following fields are mutually exclusive: agent_command, shell_command. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::WorkloadManager::V1::AgentCommand)

    AgentCommand specifies a one-time executable program for the agent to run.

    Note: The following fields are mutually exclusive: agent_command, shell_command. If a field in that set is populated, all other fields in the set will automatically be cleared.



707
708
709
710
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 707

class Command
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#shell_command::Google::Cloud::WorkloadManager::V1::ShellCommand

Returns ShellCommand is invoked via the agent's command line executor.

Note: The following fields are mutually exclusive: shell_command, agent_command. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::WorkloadManager::V1::ShellCommand)

    ShellCommand is invoked via the agent's command line executor.

    Note: The following fields are mutually exclusive: shell_command, agent_command. If a field in that set is populated, all other fields in the set will automatically be cleared.



707
708
709
710
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 707

class Command
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end