Class: Google::Cloud::WorkloadManager::V1::CreateEvaluationRequest
- Inherits:
-
Object
- Object
- Google::Cloud::WorkloadManager::V1::CreateEvaluationRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workloadmanager/v1/service.rb
Overview
Request message for the CreateEvaluation RPC.
Instance Attribute Summary collapse
-
#evaluation ⇒ ::Google::Cloud::WorkloadManager::V1::Evaluation
Required.
-
#evaluation_id ⇒ ::String
Required.
-
#parent ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#evaluation ⇒ ::Google::Cloud::WorkloadManager::V1::Evaluation
Returns Required. The resource being created.
267 268 269 270 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 267 class CreateEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#evaluation_id ⇒ ::String
Returns Required. Id of the requesting object.
267 268 269 270 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 267 class CreateEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The resource prefix of the evaluation location using the form:
projects/{project_id}/locations/{location_id}.
267 268 269 270 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 267 class CreateEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
267 268 269 270 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 267 class CreateEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |