Class: Google::Cloud::WorkloadManager::V1::Execution::Summary

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workloadmanager/v1/service.rb

Overview

Execution summary.

Instance Attribute Summary collapse

Instance Attribute Details

#failures::Integer (readonly)

Returns Output only. Number of failures.

Returns:

  • (::Integer)

    Output only. Number of failures.



428
429
430
431
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 428

class Summary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#new_failures::Integer (readonly)

Returns Output only. Number of new failures compared to the previous execution.

Returns:

  • (::Integer)

    Output only. Number of new failures compared to the previous execution.



428
429
430
431
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 428

class Summary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#new_fixes::Integer (readonly)

Returns Output only. Number of new fixes compared to the previous execution.

Returns:

  • (::Integer)

    Output only. Number of new fixes compared to the previous execution.



428
429
430
431
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 428

class Summary
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end