Class: Google::Cloud::WorkloadManager::V1::ExecutionResult

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workloadmanager/v1/service.rb

Overview

The result of an execution.

Defined Under Namespace

Modules: Type

Instance Attribute Summary collapse

Instance Attribute Details

#commands::Array<::Google::Cloud::WorkloadManager::V1::Command>

Returns The commands to remediate the violation.

Returns:



678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 678

class ExecutionResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum of execution result type.
  module Type
    # Unknown state.
    TYPE_UNSPECIFIED = 0

    # Resource successfully passed the rule.
    TYPE_PASSED = 1

    # Resource violated the rule.
    TYPE_VIOLATED = 2
  end
end

#documentation_url::String

Returns The URL for the documentation of the rule.

Returns:

  • (::String)

    The URL for the documentation of the rule.



678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 678

class ExecutionResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum of execution result type.
  module Type
    # Unknown state.
    TYPE_UNSPECIFIED = 0

    # Resource successfully passed the rule.
    TYPE_PASSED = 1

    # Resource violated the rule.
    TYPE_VIOLATED = 2
  end
end

#resource::Google::Cloud::WorkloadManager::V1::Resource

Returns The resource that violates the rule.

Returns:



678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 678

class ExecutionResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum of execution result type.
  module Type
    # Unknown state.
    TYPE_UNSPECIFIED = 0

    # Resource successfully passed the rule.
    TYPE_PASSED = 1

    # Resource violated the rule.
    TYPE_VIOLATED = 2
  end
end

#rule::String

Returns The rule that is violated in an evaluation.

Returns:

  • (::String)

    The rule that is violated in an evaluation.



678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 678

class ExecutionResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum of execution result type.
  module Type
    # Unknown state.
    TYPE_UNSPECIFIED = 0

    # Resource successfully passed the rule.
    TYPE_PASSED = 1

    # Resource violated the rule.
    TYPE_VIOLATED = 2
  end
end

#severity::String

Returns The severity of violation.

Returns:

  • (::String)

    The severity of violation.



678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 678

class ExecutionResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum of execution result type.
  module Type
    # Unknown state.
    TYPE_UNSPECIFIED = 0

    # Resource successfully passed the rule.
    TYPE_PASSED = 1

    # Resource violated the rule.
    TYPE_VIOLATED = 2
  end
end

#type::Google::Cloud::WorkloadManager::V1::ExecutionResult::Type

Returns Execution result type of the scanned resource.

Returns:



678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 678

class ExecutionResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum of execution result type.
  module Type
    # Unknown state.
    TYPE_UNSPECIFIED = 0

    # Resource successfully passed the rule.
    TYPE_PASSED = 1

    # Resource violated the rule.
    TYPE_VIOLATED = 2
  end
end

#violation_details::Google::Cloud::WorkloadManager::V1::ViolationDetails

Returns The details of violation in an evaluation result.

Returns:



678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 678

class ExecutionResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum of execution result type.
  module Type
    # Unknown state.
    TYPE_UNSPECIFIED = 0

    # Resource successfully passed the rule.
    TYPE_PASSED = 1

    # Resource violated the rule.
    TYPE_VIOLATED = 2
  end
end

#violation_message::String

Returns The violation message of an execution.

Returns:

  • (::String)

    The violation message of an execution.



678
679
680
681
682
683
684
685
686
687
688
689
690
691
692
693
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 678

class ExecutionResult
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Enum of execution result type.
  module Type
    # Unknown state.
    TYPE_UNSPECIFIED = 0

    # Resource successfully passed the rule.
    TYPE_PASSED = 1

    # Resource violated the rule.
    TYPE_VIOLATED = 2
  end
end