Class: Google::Cloud::WorkloadManager::V1::ListScannedResourcesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workloadmanager/v1/service.rb

Overview

Response message for the ListScannedResources RPC.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.

Returns:

  • (::String)

    A token, which can be sent as page_token to retrieve the next page. If this field is omitted, there are no subsequent pages.



972
973
974
975
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 972

class ListScannedResourcesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#scanned_resources::Array<::Google::Cloud::WorkloadManager::V1::ScannedResource>

Returns All scanned resources in response.

Returns:



972
973
974
975
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 972

class ListScannedResourcesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end