Class: Google::Cloud::WorkloadManager::V1::ResourceStatus

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/workloadmanager/v1/service.rb

Overview

The lifecycle status of an Evaluation resource.

Defined Under Namespace

Modules: State

Instance Attribute Summary collapse

Instance Attribute Details

#state::Google::Cloud::WorkloadManager::V1::ResourceStatus::State

Returns State of the Evaluation resource.

Returns:



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 161

class ResourceStatus
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Possible states of an evaluation, such as CREATING, ACTIVE, and DELETING.
  module State
    # The state has not been populated in this message.
    STATE_UNSPECIFIED = 0

    # Resource has an active Create operation.
    CREATING = 1

    # Resource has no outstanding operations on it or has active Update
    # operations.
    ACTIVE = 2

    # Resource has an active Delete operation.
    DELETING = 3
  end
end