Class: Google::Cloud::WorkloadManager::V1::AgentCommand
- Inherits:
-
Object
- Object
- Google::Cloud::WorkloadManager::V1::AgentCommand
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workloadmanager/v1/service.rb
Overview
An AgentCommand specifies a one-time executable program for the agent to run.
Defined Under Namespace
Classes: ParametersEntry
Instance Attribute Summary collapse
-
#command ⇒ ::String
The name of the agent one-time executable that will be invoked.
-
#parameters ⇒ ::Google::Protobuf::Map{::String => ::String}
A map of key/value pairs that can be used to specify additional one-time executable settings.
Instance Attribute Details
#command ⇒ ::String
Returns The name of the agent one-time executable that will be invoked.
720 721 722 723 724 725 726 727 728 729 730 731 732 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 720 class AgentCommand include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ParametersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |
#parameters ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns A map of key/value pairs that can be used to specify additional one-time executable settings.
720 721 722 723 724 725 726 727 728 729 730 731 732 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 720 class AgentCommand include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class ParametersEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end end |