Class: Google::Cloud::WorkloadManager::V1::Evaluation
- Inherits:
-
Object
- Object
- Google::Cloud::WorkloadManager::V1::Evaluation
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workloadmanager/v1/service.rb
Overview
Represents a Workload Manager Evaluation configuration. An Evaluation defines a set of rules to be validated against a scope of Cloud resources.
Defined Under Namespace
Modules: EvaluationType Classes: LabelsEntry
Instance Attribute Summary collapse
-
#big_query_destination ⇒ ::Google::Cloud::WorkloadManager::V1::BigQueryDestination
Optional.
-
#create_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#custom_rules_bucket ⇒ ::String
The Cloud Storage bucket name for custom rules.
-
#description ⇒ ::String
Description of the Evaluation.
-
#evaluation_type ⇒ ::Google::Cloud::WorkloadManager::V1::Evaluation::EvaluationType
Evaluation type.
-
#kms_key ⇒ ::String
Optional.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Labels as key value pairs.
-
#name ⇒ ::String
Name of resource that has the form
projects/{project_id}/locations/{location_id}/evaluations/{evaluation_id}. -
#resource_filter ⇒ ::Google::Cloud::WorkloadManager::V1::ResourceFilter
Resource filter for an evaluation defining the scope of resources to be evaluated.
-
#resource_status ⇒ ::Google::Cloud::WorkloadManager::V1::ResourceStatus
readonly
Output only.
-
#rule_names ⇒ ::Array<::String>
The names of the rules used for this evaluation.
-
#schedule ⇒ ::String
Crontab format schedule for scheduled evaluation, currently only supports the following fixed schedules: *
0 */1 * * *# Hourly *0 */6 * * *# Every 6 hours *0 */12 * * *# Every 12 hours *0 0 */1 * *# Daily *0 0 */7 * *# Weekly *0 0 */14 * *# Every 14 days *0 0 1 */1 *# Monthly. -
#update_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
Instance Attribute Details
#big_query_destination ⇒ ::Google::Cloud::WorkloadManager::V1::BigQueryDestination
Returns Optional. The BigQuery destination for detailed evaluation results. If this field is specified, the results of each evaluation execution are exported to BigQuery.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 81 class Evaluation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible types of workload evaluations like SAP, SQL Server, etc. module EvaluationType # Not specified. EVALUATION_TYPE_UNSPECIFIED = 0 # SAP best practices. SAP = 1 # SQL best practices. SQL_SERVER = 2 # Customized best practices. OTHER = 3 end end |
#create_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. [Output only] Create time stamp.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 81 class Evaluation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible types of workload evaluations like SAP, SQL Server, etc. module EvaluationType # Not specified. EVALUATION_TYPE_UNSPECIFIED = 0 # SAP best practices. SAP = 1 # SQL best practices. SQL_SERVER = 2 # Customized best practices. OTHER = 3 end end |
#custom_rules_bucket ⇒ ::String
Returns The Cloud Storage bucket name for custom rules.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 81 class Evaluation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible types of workload evaluations like SAP, SQL Server, etc. module EvaluationType # Not specified. EVALUATION_TYPE_UNSPECIFIED = 0 # SAP best practices. SAP = 1 # SQL best practices. SQL_SERVER = 2 # Customized best practices. OTHER = 3 end end |
#description ⇒ ::String
Returns Description of the Evaluation.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 81 class Evaluation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible types of workload evaluations like SAP, SQL Server, etc. module EvaluationType # Not specified. EVALUATION_TYPE_UNSPECIFIED = 0 # SAP best practices. SAP = 1 # SQL best practices. SQL_SERVER = 2 # Customized best practices. OTHER = 3 end end |
#evaluation_type ⇒ ::Google::Cloud::WorkloadManager::V1::Evaluation::EvaluationType
Returns Evaluation type.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 81 class Evaluation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible types of workload evaluations like SAP, SQL Server, etc. module EvaluationType # Not specified. EVALUATION_TYPE_UNSPECIFIED = 0 # SAP best practices. SAP = 1 # SQL best practices. SQL_SERVER = 2 # Customized best practices. OTHER = 3 end end |
#kms_key ⇒ ::String
Returns Optional. Immutable. Customer-managed encryption key name, in the format projects//locations//keyRings//cryptoKeys/. The key will be used for CMEK encryption of the evaluation resource.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 81 class Evaluation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible types of workload evaluations like SAP, SQL Server, etc. module EvaluationType # Not specified. EVALUATION_TYPE_UNSPECIFIED = 0 # SAP best practices. SAP = 1 # SQL best practices. SQL_SERVER = 2 # Customized best practices. OTHER = 3 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Labels as key value pairs.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 81 class Evaluation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible types of workload evaluations like SAP, SQL Server, etc. module EvaluationType # Not specified. EVALUATION_TYPE_UNSPECIFIED = 0 # SAP best practices. SAP = 1 # SQL best practices. SQL_SERVER = 2 # Customized best practices. OTHER = 3 end end |
#name ⇒ ::String
Returns Name of resource that has the form
projects/{project_id}/locations/{location_id}/evaluations/{evaluation_id}.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 81 class Evaluation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible types of workload evaluations like SAP, SQL Server, etc. module EvaluationType # Not specified. EVALUATION_TYPE_UNSPECIFIED = 0 # SAP best practices. SAP = 1 # SQL best practices. SQL_SERVER = 2 # Customized best practices. OTHER = 3 end end |
#resource_filter ⇒ ::Google::Cloud::WorkloadManager::V1::ResourceFilter
Returns Resource filter for an evaluation defining the scope of resources to be evaluated.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 81 class Evaluation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible types of workload evaluations like SAP, SQL Server, etc. module EvaluationType # Not specified. EVALUATION_TYPE_UNSPECIFIED = 0 # SAP best practices. SAP = 1 # SQL best practices. SQL_SERVER = 2 # Customized best practices. OTHER = 3 end end |
#resource_status ⇒ ::Google::Cloud::WorkloadManager::V1::ResourceStatus (readonly)
Returns Output only. [Output only] The current lifecycle state of the evaluation resource.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 81 class Evaluation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible types of workload evaluations like SAP, SQL Server, etc. module EvaluationType # Not specified. EVALUATION_TYPE_UNSPECIFIED = 0 # SAP best practices. SAP = 1 # SQL best practices. SQL_SERVER = 2 # Customized best practices. OTHER = 3 end end |
#rule_names ⇒ ::Array<::String>
Returns The names of the rules used for this evaluation.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 81 class Evaluation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible types of workload evaluations like SAP, SQL Server, etc. module EvaluationType # Not specified. EVALUATION_TYPE_UNSPECIFIED = 0 # SAP best practices. SAP = 1 # SQL best practices. SQL_SERVER = 2 # Customized best practices. OTHER = 3 end end |
#schedule ⇒ ::String
Returns Crontab format schedule for scheduled evaluation, currently only supports the following fixed schedules:
0 */1 * * *# Hourly0 */6 * * *# Every 6 hours0 */12 * * *# Every 12 hours0 0 */1 * *# Daily0 0 */7 * *# Weekly0 0 */14 * *# Every 14 days0 0 1 */1 *# Monthly.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 81 class Evaluation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible types of workload evaluations like SAP, SQL Server, etc. module EvaluationType # Not specified. EVALUATION_TYPE_UNSPECIFIED = 0 # SAP best practices. SAP = 1 # SQL best practices. SQL_SERVER = 2 # Customized best practices. OTHER = 3 end end |
#update_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. [Output only] Update time stamp.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 81 class Evaluation include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Possible types of workload evaluations like SAP, SQL Server, etc. module EvaluationType # Not specified. EVALUATION_TYPE_UNSPECIFIED = 0 # SAP best practices. SAP = 1 # SQL best practices. SQL_SERVER = 2 # Customized best practices. OTHER = 3 end end |