Class: Google::Cloud::WorkloadManager::V1::Execution
- Inherits:
-
Object
- Object
- Google::Cloud::WorkloadManager::V1::Execution
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workloadmanager/v1/service.rb
Overview
Execution that represents a single run of an Evaluation.
Defined Under Namespace
Modules: Engine, State, Type Classes: ExternalDataSources, LabelsEntry, Notice, Summary
Instance Attribute Summary collapse
-
#end_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#engine ⇒ ::Google::Cloud::WorkloadManager::V1::Execution::Engine
Optional.
-
#evaluation_id ⇒ ::String
readonly
Output only.
-
#external_data_sources ⇒ ::Array<::Google::Cloud::WorkloadManager::V1::Execution::ExternalDataSources>
Optional.
-
#inventory_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Labels as key value pairs.
-
#name ⇒ ::String
The name of execution resource.
-
#notices ⇒ ::Array<::Google::Cloud::WorkloadManager::V1::Execution::Notice>
readonly
Output only.
-
#result_summary ⇒ ::Google::Cloud::WorkloadManager::V1::Execution::Summary
readonly
Output only.
-
#rule_results ⇒ ::Array<::Google::Cloud::WorkloadManager::V1::RuleExecutionResult>
readonly
Output only.
-
#run_type ⇒ ::Google::Cloud::WorkloadManager::V1::Execution::Type
Type which represents whether the execution executed directly by user or scheduled according to the
Evaluation.schedulefield. -
#start_time ⇒ ::Google::Protobuf::Timestamp
readonly
Output only.
-
#state ⇒ ::Google::Cloud::WorkloadManager::V1::Execution::State
readonly
Output only.
Instance Attribute Details
#end_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. [Output only] End time stamp.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 372 class Execution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # External data sources for an execution. # @!attribute [rw] name # @return [::String] # Optional. Name of external data source. The name will be used inside the # rego/sql to refer the external data. # @!attribute [rw] uri # @return [::String] # Required. URI of external data source. example of bq table # \\{project_ID}.\\{dataset_ID}.\\{table_ID}. # @!attribute [rw] type # @return [::Google::Cloud::WorkloadManager::V1::Execution::ExternalDataSources::Type] # Required. Type of external data source. # @!attribute [rw] asset_type # @return [::String] # Required. The asset type of the external data source. # This can be a supported Cloud Asset Inventory asset type # (see https://cloud.google.com/asset-inventory/docs/supported-asset-types) # to override the default asset type, or it can be a custom type defined by # the user. class ExternalDataSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible types of external data sources like BigQuery table, etc. module Type # Unknown type. TYPE_UNSPECIFIED = 0 # BigQuery table. BIG_QUERY_TABLE = 1 end end # Additional information generated by an execution. # @!attribute [r] message # @return [::String] # Output only. Message of the notice. class Notice include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Execution summary. # @!attribute [r] failures # @return [::Integer] # Output only. Number of failures. # @!attribute [r] new_failures # @return [::Integer] # Output only. Number of new failures compared to the previous execution. # @!attribute [r] new_fixes # @return [::Integer] # Output only. Number of new fixes compared to the previous execution. class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an execution like RUNNING, SUCCEEDED, FAILED, etc. module State # State of execution is unspecified. STATE_UNSPECIFIED = 0 # The execution is running in backend service. RUNNING = 1 # The execution run succeeded. SUCCEEDED = 2 # The execution run failed. FAILED = 3 end # The type of execution, could be on demand execute or scheduled execute. module Type # Type of execution is unspecified. TYPE_UNSPECIFIED = 0 # Type of execution is one time. ONE_TIME = 1 # Type of execution is scheduled. SCHEDULED = 2 end # The engine used for the execution. module Engine # The original CG. ENGINE_UNSPECIFIED = 0 # SlimCG / Scanner. ENGINE_SCANNER = 1 # Evaluation Engine V2. V2 = 2 end end |
#engine ⇒ ::Google::Cloud::WorkloadManager::V1::Execution::Engine
Returns Optional. Engine.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 372 class Execution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # External data sources for an execution. # @!attribute [rw] name # @return [::String] # Optional. Name of external data source. The name will be used inside the # rego/sql to refer the external data. # @!attribute [rw] uri # @return [::String] # Required. URI of external data source. example of bq table # \\{project_ID}.\\{dataset_ID}.\\{table_ID}. # @!attribute [rw] type # @return [::Google::Cloud::WorkloadManager::V1::Execution::ExternalDataSources::Type] # Required. Type of external data source. # @!attribute [rw] asset_type # @return [::String] # Required. The asset type of the external data source. # This can be a supported Cloud Asset Inventory asset type # (see https://cloud.google.com/asset-inventory/docs/supported-asset-types) # to override the default asset type, or it can be a custom type defined by # the user. class ExternalDataSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible types of external data sources like BigQuery table, etc. module Type # Unknown type. TYPE_UNSPECIFIED = 0 # BigQuery table. BIG_QUERY_TABLE = 1 end end # Additional information generated by an execution. # @!attribute [r] message # @return [::String] # Output only. Message of the notice. class Notice include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Execution summary. # @!attribute [r] failures # @return [::Integer] # Output only. Number of failures. # @!attribute [r] new_failures # @return [::Integer] # Output only. Number of new failures compared to the previous execution. # @!attribute [r] new_fixes # @return [::Integer] # Output only. Number of new fixes compared to the previous execution. class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an execution like RUNNING, SUCCEEDED, FAILED, etc. module State # State of execution is unspecified. STATE_UNSPECIFIED = 0 # The execution is running in backend service. RUNNING = 1 # The execution run succeeded. SUCCEEDED = 2 # The execution run failed. FAILED = 3 end # The type of execution, could be on demand execute or scheduled execute. module Type # Type of execution is unspecified. TYPE_UNSPECIFIED = 0 # Type of execution is one time. ONE_TIME = 1 # Type of execution is scheduled. SCHEDULED = 2 end # The engine used for the execution. module Engine # The original CG. ENGINE_UNSPECIFIED = 0 # SlimCG / Scanner. ENGINE_SCANNER = 1 # Evaluation Engine V2. V2 = 2 end end |
#evaluation_id ⇒ ::String (readonly)
Returns Output only. [Output only] Evaluation ID.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 372 class Execution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # External data sources for an execution. # @!attribute [rw] name # @return [::String] # Optional. Name of external data source. The name will be used inside the # rego/sql to refer the external data. # @!attribute [rw] uri # @return [::String] # Required. URI of external data source. example of bq table # \\{project_ID}.\\{dataset_ID}.\\{table_ID}. # @!attribute [rw] type # @return [::Google::Cloud::WorkloadManager::V1::Execution::ExternalDataSources::Type] # Required. Type of external data source. # @!attribute [rw] asset_type # @return [::String] # Required. The asset type of the external data source. # This can be a supported Cloud Asset Inventory asset type # (see https://cloud.google.com/asset-inventory/docs/supported-asset-types) # to override the default asset type, or it can be a custom type defined by # the user. class ExternalDataSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible types of external data sources like BigQuery table, etc. module Type # Unknown type. TYPE_UNSPECIFIED = 0 # BigQuery table. BIG_QUERY_TABLE = 1 end end # Additional information generated by an execution. # @!attribute [r] message # @return [::String] # Output only. Message of the notice. class Notice include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Execution summary. # @!attribute [r] failures # @return [::Integer] # Output only. Number of failures. # @!attribute [r] new_failures # @return [::Integer] # Output only. Number of new failures compared to the previous execution. # @!attribute [r] new_fixes # @return [::Integer] # Output only. Number of new fixes compared to the previous execution. class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an execution like RUNNING, SUCCEEDED, FAILED, etc. module State # State of execution is unspecified. STATE_UNSPECIFIED = 0 # The execution is running in backend service. RUNNING = 1 # The execution run succeeded. SUCCEEDED = 2 # The execution run failed. FAILED = 3 end # The type of execution, could be on demand execute or scheduled execute. module Type # Type of execution is unspecified. TYPE_UNSPECIFIED = 0 # Type of execution is one time. ONE_TIME = 1 # Type of execution is scheduled. SCHEDULED = 2 end # The engine used for the execution. module Engine # The original CG. ENGINE_UNSPECIFIED = 0 # SlimCG / Scanner. ENGINE_SCANNER = 1 # Evaluation Engine V2. V2 = 2 end end |
#external_data_sources ⇒ ::Array<::Google::Cloud::WorkloadManager::V1::Execution::ExternalDataSources>
Returns Optional. External data sources.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 372 class Execution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # External data sources for an execution. # @!attribute [rw] name # @return [::String] # Optional. Name of external data source. The name will be used inside the # rego/sql to refer the external data. # @!attribute [rw] uri # @return [::String] # Required. URI of external data source. example of bq table # \\{project_ID}.\\{dataset_ID}.\\{table_ID}. # @!attribute [rw] type # @return [::Google::Cloud::WorkloadManager::V1::Execution::ExternalDataSources::Type] # Required. Type of external data source. # @!attribute [rw] asset_type # @return [::String] # Required. The asset type of the external data source. # This can be a supported Cloud Asset Inventory asset type # (see https://cloud.google.com/asset-inventory/docs/supported-asset-types) # to override the default asset type, or it can be a custom type defined by # the user. class ExternalDataSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible types of external data sources like BigQuery table, etc. module Type # Unknown type. TYPE_UNSPECIFIED = 0 # BigQuery table. BIG_QUERY_TABLE = 1 end end # Additional information generated by an execution. # @!attribute [r] message # @return [::String] # Output only. Message of the notice. class Notice include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Execution summary. # @!attribute [r] failures # @return [::Integer] # Output only. Number of failures. # @!attribute [r] new_failures # @return [::Integer] # Output only. Number of new failures compared to the previous execution. # @!attribute [r] new_fixes # @return [::Integer] # Output only. Number of new fixes compared to the previous execution. class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an execution like RUNNING, SUCCEEDED, FAILED, etc. module State # State of execution is unspecified. STATE_UNSPECIFIED = 0 # The execution is running in backend service. RUNNING = 1 # The execution run succeeded. SUCCEEDED = 2 # The execution run failed. FAILED = 3 end # The type of execution, could be on demand execute or scheduled execute. module Type # Type of execution is unspecified. TYPE_UNSPECIFIED = 0 # Type of execution is one time. ONE_TIME = 1 # Type of execution is scheduled. SCHEDULED = 2 end # The engine used for the execution. module Engine # The original CG. ENGINE_UNSPECIFIED = 0 # SlimCG / Scanner. ENGINE_SCANNER = 1 # Evaluation Engine V2. V2 = 2 end end |
#inventory_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. [Output only] Inventory time stamp.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 372 class Execution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # External data sources for an execution. # @!attribute [rw] name # @return [::String] # Optional. Name of external data source. The name will be used inside the # rego/sql to refer the external data. # @!attribute [rw] uri # @return [::String] # Required. URI of external data source. example of bq table # \\{project_ID}.\\{dataset_ID}.\\{table_ID}. # @!attribute [rw] type # @return [::Google::Cloud::WorkloadManager::V1::Execution::ExternalDataSources::Type] # Required. Type of external data source. # @!attribute [rw] asset_type # @return [::String] # Required. The asset type of the external data source. # This can be a supported Cloud Asset Inventory asset type # (see https://cloud.google.com/asset-inventory/docs/supported-asset-types) # to override the default asset type, or it can be a custom type defined by # the user. class ExternalDataSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible types of external data sources like BigQuery table, etc. module Type # Unknown type. TYPE_UNSPECIFIED = 0 # BigQuery table. BIG_QUERY_TABLE = 1 end end # Additional information generated by an execution. # @!attribute [r] message # @return [::String] # Output only. Message of the notice. class Notice include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Execution summary. # @!attribute [r] failures # @return [::Integer] # Output only. Number of failures. # @!attribute [r] new_failures # @return [::Integer] # Output only. Number of new failures compared to the previous execution. # @!attribute [r] new_fixes # @return [::Integer] # Output only. Number of new fixes compared to the previous execution. class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an execution like RUNNING, SUCCEEDED, FAILED, etc. module State # State of execution is unspecified. STATE_UNSPECIFIED = 0 # The execution is running in backend service. RUNNING = 1 # The execution run succeeded. SUCCEEDED = 2 # The execution run failed. FAILED = 3 end # The type of execution, could be on demand execute or scheduled execute. module Type # Type of execution is unspecified. TYPE_UNSPECIFIED = 0 # Type of execution is one time. ONE_TIME = 1 # Type of execution is scheduled. SCHEDULED = 2 end # The engine used for the execution. module Engine # The original CG. ENGINE_UNSPECIFIED = 0 # SlimCG / Scanner. ENGINE_SCANNER = 1 # Evaluation Engine V2. V2 = 2 end end |
#labels ⇒ ::Google::Protobuf::Map{::String => ::String}
Returns Labels as key value pairs.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 372 class Execution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # External data sources for an execution. # @!attribute [rw] name # @return [::String] # Optional. Name of external data source. The name will be used inside the # rego/sql to refer the external data. # @!attribute [rw] uri # @return [::String] # Required. URI of external data source. example of bq table # \\{project_ID}.\\{dataset_ID}.\\{table_ID}. # @!attribute [rw] type # @return [::Google::Cloud::WorkloadManager::V1::Execution::ExternalDataSources::Type] # Required. Type of external data source. # @!attribute [rw] asset_type # @return [::String] # Required. The asset type of the external data source. # This can be a supported Cloud Asset Inventory asset type # (see https://cloud.google.com/asset-inventory/docs/supported-asset-types) # to override the default asset type, or it can be a custom type defined by # the user. class ExternalDataSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible types of external data sources like BigQuery table, etc. module Type # Unknown type. TYPE_UNSPECIFIED = 0 # BigQuery table. BIG_QUERY_TABLE = 1 end end # Additional information generated by an execution. # @!attribute [r] message # @return [::String] # Output only. Message of the notice. class Notice include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Execution summary. # @!attribute [r] failures # @return [::Integer] # Output only. Number of failures. # @!attribute [r] new_failures # @return [::Integer] # Output only. Number of new failures compared to the previous execution. # @!attribute [r] new_fixes # @return [::Integer] # Output only. Number of new fixes compared to the previous execution. class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an execution like RUNNING, SUCCEEDED, FAILED, etc. module State # State of execution is unspecified. STATE_UNSPECIFIED = 0 # The execution is running in backend service. RUNNING = 1 # The execution run succeeded. SUCCEEDED = 2 # The execution run failed. FAILED = 3 end # The type of execution, could be on demand execute or scheduled execute. module Type # Type of execution is unspecified. TYPE_UNSPECIFIED = 0 # Type of execution is one time. ONE_TIME = 1 # Type of execution is scheduled. SCHEDULED = 2 end # The engine used for the execution. module Engine # The original CG. ENGINE_UNSPECIFIED = 0 # SlimCG / Scanner. ENGINE_SCANNER = 1 # Evaluation Engine V2. V2 = 2 end end |
#name ⇒ ::String
Returns The name of execution resource. The format is projects/{project}/locations/{location}/evaluations/{evaluation}/executions/{execution}.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 372 class Execution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # External data sources for an execution. # @!attribute [rw] name # @return [::String] # Optional. Name of external data source. The name will be used inside the # rego/sql to refer the external data. # @!attribute [rw] uri # @return [::String] # Required. URI of external data source. example of bq table # \\{project_ID}.\\{dataset_ID}.\\{table_ID}. # @!attribute [rw] type # @return [::Google::Cloud::WorkloadManager::V1::Execution::ExternalDataSources::Type] # Required. Type of external data source. # @!attribute [rw] asset_type # @return [::String] # Required. The asset type of the external data source. # This can be a supported Cloud Asset Inventory asset type # (see https://cloud.google.com/asset-inventory/docs/supported-asset-types) # to override the default asset type, or it can be a custom type defined by # the user. class ExternalDataSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible types of external data sources like BigQuery table, etc. module Type # Unknown type. TYPE_UNSPECIFIED = 0 # BigQuery table. BIG_QUERY_TABLE = 1 end end # Additional information generated by an execution. # @!attribute [r] message # @return [::String] # Output only. Message of the notice. class Notice include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Execution summary. # @!attribute [r] failures # @return [::Integer] # Output only. Number of failures. # @!attribute [r] new_failures # @return [::Integer] # Output only. Number of new failures compared to the previous execution. # @!attribute [r] new_fixes # @return [::Integer] # Output only. Number of new fixes compared to the previous execution. class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an execution like RUNNING, SUCCEEDED, FAILED, etc. module State # State of execution is unspecified. STATE_UNSPECIFIED = 0 # The execution is running in backend service. RUNNING = 1 # The execution run succeeded. SUCCEEDED = 2 # The execution run failed. FAILED = 3 end # The type of execution, could be on demand execute or scheduled execute. module Type # Type of execution is unspecified. TYPE_UNSPECIFIED = 0 # Type of execution is one time. ONE_TIME = 1 # Type of execution is scheduled. SCHEDULED = 2 end # The engine used for the execution. module Engine # The original CG. ENGINE_UNSPECIFIED = 0 # SlimCG / Scanner. ENGINE_SCANNER = 1 # Evaluation Engine V2. V2 = 2 end end |
#notices ⇒ ::Array<::Google::Cloud::WorkloadManager::V1::Execution::Notice> (readonly)
Returns Output only. Additional information generated by the execution.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 372 class Execution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # External data sources for an execution. # @!attribute [rw] name # @return [::String] # Optional. Name of external data source. The name will be used inside the # rego/sql to refer the external data. # @!attribute [rw] uri # @return [::String] # Required. URI of external data source. example of bq table # \\{project_ID}.\\{dataset_ID}.\\{table_ID}. # @!attribute [rw] type # @return [::Google::Cloud::WorkloadManager::V1::Execution::ExternalDataSources::Type] # Required. Type of external data source. # @!attribute [rw] asset_type # @return [::String] # Required. The asset type of the external data source. # This can be a supported Cloud Asset Inventory asset type # (see https://cloud.google.com/asset-inventory/docs/supported-asset-types) # to override the default asset type, or it can be a custom type defined by # the user. class ExternalDataSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible types of external data sources like BigQuery table, etc. module Type # Unknown type. TYPE_UNSPECIFIED = 0 # BigQuery table. BIG_QUERY_TABLE = 1 end end # Additional information generated by an execution. # @!attribute [r] message # @return [::String] # Output only. Message of the notice. class Notice include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Execution summary. # @!attribute [r] failures # @return [::Integer] # Output only. Number of failures. # @!attribute [r] new_failures # @return [::Integer] # Output only. Number of new failures compared to the previous execution. # @!attribute [r] new_fixes # @return [::Integer] # Output only. Number of new fixes compared to the previous execution. class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an execution like RUNNING, SUCCEEDED, FAILED, etc. module State # State of execution is unspecified. STATE_UNSPECIFIED = 0 # The execution is running in backend service. RUNNING = 1 # The execution run succeeded. SUCCEEDED = 2 # The execution run failed. FAILED = 3 end # The type of execution, could be on demand execute or scheduled execute. module Type # Type of execution is unspecified. TYPE_UNSPECIFIED = 0 # Type of execution is one time. ONE_TIME = 1 # Type of execution is scheduled. SCHEDULED = 2 end # The engine used for the execution. module Engine # The original CG. ENGINE_UNSPECIFIED = 0 # SlimCG / Scanner. ENGINE_SCANNER = 1 # Evaluation Engine V2. V2 = 2 end end |
#result_summary ⇒ ::Google::Cloud::WorkloadManager::V1::Execution::Summary (readonly)
Returns Output only. [Output only] Result summary for the execution.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 372 class Execution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # External data sources for an execution. # @!attribute [rw] name # @return [::String] # Optional. Name of external data source. The name will be used inside the # rego/sql to refer the external data. # @!attribute [rw] uri # @return [::String] # Required. URI of external data source. example of bq table # \\{project_ID}.\\{dataset_ID}.\\{table_ID}. # @!attribute [rw] type # @return [::Google::Cloud::WorkloadManager::V1::Execution::ExternalDataSources::Type] # Required. Type of external data source. # @!attribute [rw] asset_type # @return [::String] # Required. The asset type of the external data source. # This can be a supported Cloud Asset Inventory asset type # (see https://cloud.google.com/asset-inventory/docs/supported-asset-types) # to override the default asset type, or it can be a custom type defined by # the user. class ExternalDataSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible types of external data sources like BigQuery table, etc. module Type # Unknown type. TYPE_UNSPECIFIED = 0 # BigQuery table. BIG_QUERY_TABLE = 1 end end # Additional information generated by an execution. # @!attribute [r] message # @return [::String] # Output only. Message of the notice. class Notice include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Execution summary. # @!attribute [r] failures # @return [::Integer] # Output only. Number of failures. # @!attribute [r] new_failures # @return [::Integer] # Output only. Number of new failures compared to the previous execution. # @!attribute [r] new_fixes # @return [::Integer] # Output only. Number of new fixes compared to the previous execution. class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an execution like RUNNING, SUCCEEDED, FAILED, etc. module State # State of execution is unspecified. STATE_UNSPECIFIED = 0 # The execution is running in backend service. RUNNING = 1 # The execution run succeeded. SUCCEEDED = 2 # The execution run failed. FAILED = 3 end # The type of execution, could be on demand execute or scheduled execute. module Type # Type of execution is unspecified. TYPE_UNSPECIFIED = 0 # Type of execution is one time. ONE_TIME = 1 # Type of execution is scheduled. SCHEDULED = 2 end # The engine used for the execution. module Engine # The original CG. ENGINE_UNSPECIFIED = 0 # SlimCG / Scanner. ENGINE_SCANNER = 1 # Evaluation Engine V2. V2 = 2 end end |
#rule_results ⇒ ::Array<::Google::Cloud::WorkloadManager::V1::RuleExecutionResult> (readonly)
Returns Output only. Execution result summary per rule.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 372 class Execution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # External data sources for an execution. # @!attribute [rw] name # @return [::String] # Optional. Name of external data source. The name will be used inside the # rego/sql to refer the external data. # @!attribute [rw] uri # @return [::String] # Required. URI of external data source. example of bq table # \\{project_ID}.\\{dataset_ID}.\\{table_ID}. # @!attribute [rw] type # @return [::Google::Cloud::WorkloadManager::V1::Execution::ExternalDataSources::Type] # Required. Type of external data source. # @!attribute [rw] asset_type # @return [::String] # Required. The asset type of the external data source. # This can be a supported Cloud Asset Inventory asset type # (see https://cloud.google.com/asset-inventory/docs/supported-asset-types) # to override the default asset type, or it can be a custom type defined by # the user. class ExternalDataSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible types of external data sources like BigQuery table, etc. module Type # Unknown type. TYPE_UNSPECIFIED = 0 # BigQuery table. BIG_QUERY_TABLE = 1 end end # Additional information generated by an execution. # @!attribute [r] message # @return [::String] # Output only. Message of the notice. class Notice include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Execution summary. # @!attribute [r] failures # @return [::Integer] # Output only. Number of failures. # @!attribute [r] new_failures # @return [::Integer] # Output only. Number of new failures compared to the previous execution. # @!attribute [r] new_fixes # @return [::Integer] # Output only. Number of new fixes compared to the previous execution. class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an execution like RUNNING, SUCCEEDED, FAILED, etc. module State # State of execution is unspecified. STATE_UNSPECIFIED = 0 # The execution is running in backend service. RUNNING = 1 # The execution run succeeded. SUCCEEDED = 2 # The execution run failed. FAILED = 3 end # The type of execution, could be on demand execute or scheduled execute. module Type # Type of execution is unspecified. TYPE_UNSPECIFIED = 0 # Type of execution is one time. ONE_TIME = 1 # Type of execution is scheduled. SCHEDULED = 2 end # The engine used for the execution. module Engine # The original CG. ENGINE_UNSPECIFIED = 0 # SlimCG / Scanner. ENGINE_SCANNER = 1 # Evaluation Engine V2. V2 = 2 end end |
#run_type ⇒ ::Google::Cloud::WorkloadManager::V1::Execution::Type
Returns Type which represents whether the execution executed directly by user or
scheduled according to the Evaluation.schedule field.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 372 class Execution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # External data sources for an execution. # @!attribute [rw] name # @return [::String] # Optional. Name of external data source. The name will be used inside the # rego/sql to refer the external data. # @!attribute [rw] uri # @return [::String] # Required. URI of external data source. example of bq table # \\{project_ID}.\\{dataset_ID}.\\{table_ID}. # @!attribute [rw] type # @return [::Google::Cloud::WorkloadManager::V1::Execution::ExternalDataSources::Type] # Required. Type of external data source. # @!attribute [rw] asset_type # @return [::String] # Required. The asset type of the external data source. # This can be a supported Cloud Asset Inventory asset type # (see https://cloud.google.com/asset-inventory/docs/supported-asset-types) # to override the default asset type, or it can be a custom type defined by # the user. class ExternalDataSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible types of external data sources like BigQuery table, etc. module Type # Unknown type. TYPE_UNSPECIFIED = 0 # BigQuery table. BIG_QUERY_TABLE = 1 end end # Additional information generated by an execution. # @!attribute [r] message # @return [::String] # Output only. Message of the notice. class Notice include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Execution summary. # @!attribute [r] failures # @return [::Integer] # Output only. Number of failures. # @!attribute [r] new_failures # @return [::Integer] # Output only. Number of new failures compared to the previous execution. # @!attribute [r] new_fixes # @return [::Integer] # Output only. Number of new fixes compared to the previous execution. class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an execution like RUNNING, SUCCEEDED, FAILED, etc. module State # State of execution is unspecified. STATE_UNSPECIFIED = 0 # The execution is running in backend service. RUNNING = 1 # The execution run succeeded. SUCCEEDED = 2 # The execution run failed. FAILED = 3 end # The type of execution, could be on demand execute or scheduled execute. module Type # Type of execution is unspecified. TYPE_UNSPECIFIED = 0 # Type of execution is one time. ONE_TIME = 1 # Type of execution is scheduled. SCHEDULED = 2 end # The engine used for the execution. module Engine # The original CG. ENGINE_UNSPECIFIED = 0 # SlimCG / Scanner. ENGINE_SCANNER = 1 # Evaluation Engine V2. V2 = 2 end end |
#start_time ⇒ ::Google::Protobuf::Timestamp (readonly)
Returns Output only. [Output only] Start time stamp.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 372 class Execution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # External data sources for an execution. # @!attribute [rw] name # @return [::String] # Optional. Name of external data source. The name will be used inside the # rego/sql to refer the external data. # @!attribute [rw] uri # @return [::String] # Required. URI of external data source. example of bq table # \\{project_ID}.\\{dataset_ID}.\\{table_ID}. # @!attribute [rw] type # @return [::Google::Cloud::WorkloadManager::V1::Execution::ExternalDataSources::Type] # Required. Type of external data source. # @!attribute [rw] asset_type # @return [::String] # Required. The asset type of the external data source. # This can be a supported Cloud Asset Inventory asset type # (see https://cloud.google.com/asset-inventory/docs/supported-asset-types) # to override the default asset type, or it can be a custom type defined by # the user. class ExternalDataSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible types of external data sources like BigQuery table, etc. module Type # Unknown type. TYPE_UNSPECIFIED = 0 # BigQuery table. BIG_QUERY_TABLE = 1 end end # Additional information generated by an execution. # @!attribute [r] message # @return [::String] # Output only. Message of the notice. class Notice include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Execution summary. # @!attribute [r] failures # @return [::Integer] # Output only. Number of failures. # @!attribute [r] new_failures # @return [::Integer] # Output only. Number of new failures compared to the previous execution. # @!attribute [r] new_fixes # @return [::Integer] # Output only. Number of new fixes compared to the previous execution. class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an execution like RUNNING, SUCCEEDED, FAILED, etc. module State # State of execution is unspecified. STATE_UNSPECIFIED = 0 # The execution is running in backend service. RUNNING = 1 # The execution run succeeded. SUCCEEDED = 2 # The execution run failed. FAILED = 3 end # The type of execution, could be on demand execute or scheduled execute. module Type # Type of execution is unspecified. TYPE_UNSPECIFIED = 0 # Type of execution is one time. ONE_TIME = 1 # Type of execution is scheduled. SCHEDULED = 2 end # The engine used for the execution. module Engine # The original CG. ENGINE_UNSPECIFIED = 0 # SlimCG / Scanner. ENGINE_SCANNER = 1 # Evaluation Engine V2. V2 = 2 end end |
#state ⇒ ::Google::Cloud::WorkloadManager::V1::Execution::State (readonly)
Returns Output only. [Output only] State.
372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 372 class Execution include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # External data sources for an execution. # @!attribute [rw] name # @return [::String] # Optional. Name of external data source. The name will be used inside the # rego/sql to refer the external data. # @!attribute [rw] uri # @return [::String] # Required. URI of external data source. example of bq table # \\{project_ID}.\\{dataset_ID}.\\{table_ID}. # @!attribute [rw] type # @return [::Google::Cloud::WorkloadManager::V1::Execution::ExternalDataSources::Type] # Required. Type of external data source. # @!attribute [rw] asset_type # @return [::String] # Required. The asset type of the external data source. # This can be a supported Cloud Asset Inventory asset type # (see https://cloud.google.com/asset-inventory/docs/supported-asset-types) # to override the default asset type, or it can be a custom type defined by # the user. class ExternalDataSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible types of external data sources like BigQuery table, etc. module Type # Unknown type. TYPE_UNSPECIFIED = 0 # BigQuery table. BIG_QUERY_TABLE = 1 end end # Additional information generated by an execution. # @!attribute [r] message # @return [::String] # Output only. Message of the notice. class Notice include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # Execution summary. # @!attribute [r] failures # @return [::Integer] # Output only. Number of failures. # @!attribute [r] new_failures # @return [::Integer] # Output only. Number of new failures compared to the previous execution. # @!attribute [r] new_fixes # @return [::Integer] # Output only. Number of new fixes compared to the previous execution. class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # @!attribute [rw] key # @return [::String] # @!attribute [rw] value # @return [::String] class LabelsEntry include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end # The possible states of an execution like RUNNING, SUCCEEDED, FAILED, etc. module State # State of execution is unspecified. STATE_UNSPECIFIED = 0 # The execution is running in backend service. RUNNING = 1 # The execution run succeeded. SUCCEEDED = 2 # The execution run failed. FAILED = 3 end # The type of execution, could be on demand execute or scheduled execute. module Type # Type of execution is unspecified. TYPE_UNSPECIFIED = 0 # Type of execution is one time. ONE_TIME = 1 # Type of execution is scheduled. SCHEDULED = 2 end # The engine used for the execution. module Engine # The original CG. ENGINE_UNSPECIFIED = 0 # SlimCG / Scanner. ENGINE_SCANNER = 1 # Evaluation Engine V2. V2 = 2 end end |