Class: Google::Cloud::WorkloadManager::V1::Execution::ExternalDataSources
- Inherits:
-
Object
- Object
- Google::Cloud::WorkloadManager::V1::Execution::ExternalDataSources
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workloadmanager/v1/service.rb
Overview
External data sources for an execution.
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#asset_type ⇒ ::String
Required.
-
#name ⇒ ::String
Optional.
-
#type ⇒ ::Google::Cloud::WorkloadManager::V1::Execution::ExternalDataSources::Type
Required.
-
#uri ⇒ ::String
Required.
Instance Attribute Details
#asset_type ⇒ ::String
Returns Required. The asset type of the external data source. This can be a supported Cloud Asset Inventory asset type (see https://cloud.google.com/asset-inventory/docs/supported-asset-types) to override the default asset type, or it can be a custom type defined by the user.
395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 395 class ExternalDataSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible types of external data sources like BigQuery table, etc. module Type # Unknown type. TYPE_UNSPECIFIED = 0 # BigQuery table. BIG_QUERY_TABLE = 1 end end |
#name ⇒ ::String
Returns Optional. Name of external data source. The name will be used inside the rego/sql to refer the external data.
395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 395 class ExternalDataSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible types of external data sources like BigQuery table, etc. module Type # Unknown type. TYPE_UNSPECIFIED = 0 # BigQuery table. BIG_QUERY_TABLE = 1 end end |
#type ⇒ ::Google::Cloud::WorkloadManager::V1::Execution::ExternalDataSources::Type
Returns Required. Type of external data source.
395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 395 class ExternalDataSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible types of external data sources like BigQuery table, etc. module Type # Unknown type. TYPE_UNSPECIFIED = 0 # BigQuery table. BIG_QUERY_TABLE = 1 end end |
#uri ⇒ ::String
Returns Required. URI of external data source. example of bq table {project_ID}.{dataset_ID}.{table_ID}.
395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 395 class ExternalDataSources include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Possible types of external data sources like BigQuery table, etc. module Type # Unknown type. TYPE_UNSPECIFIED = 0 # BigQuery table. BIG_QUERY_TABLE = 1 end end |