Class: Google::Cloud::WorkloadManager::V1::Execution::Summary
- Inherits:
-
Object
- Object
- Google::Cloud::WorkloadManager::V1::Execution::Summary
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workloadmanager/v1/service.rb
Overview
Execution summary.
Instance Attribute Summary collapse
-
#failures ⇒ ::Integer
readonly
Output only.
-
#new_failures ⇒ ::Integer
readonly
Output only.
-
#new_fixes ⇒ ::Integer
readonly
Output only.
Instance Attribute Details
#failures ⇒ ::Integer (readonly)
Returns Output only. Number of failures.
428 429 430 431 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 428 class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#new_failures ⇒ ::Integer (readonly)
Returns Output only. Number of new failures compared to the previous execution.
428 429 430 431 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 428 class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#new_fixes ⇒ ::Integer (readonly)
Returns Output only. Number of new fixes compared to the previous execution.
428 429 430 431 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 428 class Summary include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |