Class: Google::Cloud::WorkloadManager::V1::ExecutionResult
- Inherits:
-
Object
- Object
- Google::Cloud::WorkloadManager::V1::ExecutionResult
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workloadmanager/v1/service.rb
Overview
The result of an execution.
Defined Under Namespace
Modules: Type
Instance Attribute Summary collapse
-
#commands ⇒ ::Array<::Google::Cloud::WorkloadManager::V1::Command>
The commands to remediate the violation.
-
#documentation_url ⇒ ::String
The URL for the documentation of the rule.
-
#resource ⇒ ::Google::Cloud::WorkloadManager::V1::Resource
The resource that violates the rule.
-
#rule ⇒ ::String
The rule that is violated in an evaluation.
-
#severity ⇒ ::String
The severity of violation.
-
#type ⇒ ::Google::Cloud::WorkloadManager::V1::ExecutionResult::Type
Execution result type of the scanned resource.
-
#violation_details ⇒ ::Google::Cloud::WorkloadManager::V1::ViolationDetails
The details of violation in an evaluation result.
-
#violation_message ⇒ ::String
The violation message of an execution.
Instance Attribute Details
#commands ⇒ ::Array<::Google::Cloud::WorkloadManager::V1::Command>
Returns The commands to remediate the violation.
678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 678 class ExecutionResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum of execution result type. module Type # Unknown state. TYPE_UNSPECIFIED = 0 # Resource successfully passed the rule. TYPE_PASSED = 1 # Resource violated the rule. TYPE_VIOLATED = 2 end end |
#documentation_url ⇒ ::String
Returns The URL for the documentation of the rule.
678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 678 class ExecutionResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum of execution result type. module Type # Unknown state. TYPE_UNSPECIFIED = 0 # Resource successfully passed the rule. TYPE_PASSED = 1 # Resource violated the rule. TYPE_VIOLATED = 2 end end |
#resource ⇒ ::Google::Cloud::WorkloadManager::V1::Resource
Returns The resource that violates the rule.
678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 678 class ExecutionResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum of execution result type. module Type # Unknown state. TYPE_UNSPECIFIED = 0 # Resource successfully passed the rule. TYPE_PASSED = 1 # Resource violated the rule. TYPE_VIOLATED = 2 end end |
#rule ⇒ ::String
Returns The rule that is violated in an evaluation.
678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 678 class ExecutionResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum of execution result type. module Type # Unknown state. TYPE_UNSPECIFIED = 0 # Resource successfully passed the rule. TYPE_PASSED = 1 # Resource violated the rule. TYPE_VIOLATED = 2 end end |
#severity ⇒ ::String
Returns The severity of violation.
678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 678 class ExecutionResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum of execution result type. module Type # Unknown state. TYPE_UNSPECIFIED = 0 # Resource successfully passed the rule. TYPE_PASSED = 1 # Resource violated the rule. TYPE_VIOLATED = 2 end end |
#type ⇒ ::Google::Cloud::WorkloadManager::V1::ExecutionResult::Type
Returns Execution result type of the scanned resource.
678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 678 class ExecutionResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum of execution result type. module Type # Unknown state. TYPE_UNSPECIFIED = 0 # Resource successfully passed the rule. TYPE_PASSED = 1 # Resource violated the rule. TYPE_VIOLATED = 2 end end |
#violation_details ⇒ ::Google::Cloud::WorkloadManager::V1::ViolationDetails
Returns The details of violation in an evaluation result.
678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 678 class ExecutionResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum of execution result type. module Type # Unknown state. TYPE_UNSPECIFIED = 0 # Resource successfully passed the rule. TYPE_PASSED = 1 # Resource violated the rule. TYPE_VIOLATED = 2 end end |
#violation_message ⇒ ::String
Returns The violation message of an execution.
678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 678 class ExecutionResult include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Enum of execution result type. module Type # Unknown state. TYPE_UNSPECIFIED = 0 # Resource successfully passed the rule. TYPE_PASSED = 1 # Resource violated the rule. TYPE_VIOLATED = 2 end end |