Class: Google::Cloud::WorkloadManager::V1::ListRulesRequest
- Inherits:
-
Object
- Object
- Google::Cloud::WorkloadManager::V1::ListRulesRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workloadmanager/v1/service.rb
Overview
Request message for the ListRules RPC.
Instance Attribute Summary collapse
-
#custom_rules_bucket ⇒ ::String
The Cloud Storage bucket name for custom rules.
-
#evaluation_type ⇒ ::Google::Cloud::WorkloadManager::V1::Evaluation::EvaluationType
Optional.
-
#filter ⇒ ::String
Filter based on primary_category, secondary_category.
-
#page_size ⇒ ::Integer
Requested page size.
-
#page_token ⇒ ::String
A token identifying a page of results the server should return.
-
#parent ⇒ ::String
Required.
Instance Attribute Details
#custom_rules_bucket ⇒ ::String
Returns The Cloud Storage bucket name for custom rules.
925 926 927 928 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 925 class ListRulesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#evaluation_type ⇒ ::Google::Cloud::WorkloadManager::V1::Evaluation::EvaluationType
Returns Optional. The evaluation type of the rules will be applied to. The Cloud Storage bucket name for custom rules.
925 926 927 928 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 925 class ListRulesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#filter ⇒ ::String
Returns Filter based on primary_category, secondary_category.
925 926 927 928 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 925 class ListRulesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_size ⇒ ::Integer
Returns Requested page size. Server may return fewer items than requested. If unspecified, server will pick an appropriate default.
925 926 927 928 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 925 class ListRulesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#page_token ⇒ ::String
Returns A token identifying a page of results the server should return.
925 926 927 928 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 925 class ListRulesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#parent ⇒ ::String
Returns Required. The [project] on which to execute the request. The format is: projects/{project_id}/locations/{location} Currently, the pre-defined rules are global available to all projects and all regions.
925 926 927 928 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 925 class ListRulesRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |