Module: Google::Cloud::WorkloadManager::V1::ResourceStatus::State
- Defined in:
- proto_docs/google/cloud/workloadmanager/v1/service.rb
Overview
Possible states of an evaluation, such as CREATING, ACTIVE, and DELETING.
Constant Summary collapse
- STATE_UNSPECIFIED =
The state has not been populated in this message.
0- CREATING =
Resource has an active Create operation.
1- ACTIVE =
Resource has no outstanding operations on it or has active Update operations.
2- DELETING =
Resource has an active Delete operation.
3