Class: Google::Cloud::WorkloadManager::V1::Rule
- Inherits:
-
Object
- Object
- Google::Cloud::WorkloadManager::V1::Rule
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workloadmanager/v1/service.rb
Overview
A rule to be evaluated.
Defined Under Namespace
Modules: RuleType
Instance Attribute Summary collapse
-
#asset_type ⇒ ::String
The CAI asset type of the rule is evaluating, for joined asset types, it will be the corresponding primary asset types.
-
#description ⇒ ::String
Describe rule in plain language.
-
#display_name ⇒ ::String
The name display in UI.
-
#error_message ⇒ ::String
The message template for rule.
-
#name ⇒ ::String
Rule name.
-
#primary_category ⇒ ::String
The primary category.
-
#remediation ⇒ ::String
The remediation for the rule.
-
#revision_id ⇒ ::String
readonly
Output only.
-
#rule_type ⇒ ::Google::Cloud::WorkloadManager::V1::Rule::RuleType
The type of the rule.
-
#secondary_category ⇒ ::String
The secondary category.
-
#severity ⇒ ::String
The severity of the rule.
-
#tags ⇒ ::Array<::String>
List of user-defined tags.
-
#uri ⇒ ::String
The document url for the rule.
Instance Attribute Details
#asset_type ⇒ ::String
Returns The CAI asset type of the rule is evaluating, for joined asset types, it will be the corresponding primary asset types.
884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 884 class Rule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the rule. module RuleType # Not specified. RULE_TYPE_UNSPECIFIED = 0 # Baseline rules. BASELINE = 1 # Custom rules. CUSTOM = 2 end end |
#description ⇒ ::String
Returns Describe rule in plain language.
884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 884 class Rule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the rule. module RuleType # Not specified. RULE_TYPE_UNSPECIFIED = 0 # Baseline rules. BASELINE = 1 # Custom rules. CUSTOM = 2 end end |
#display_name ⇒ ::String
Returns The name display in UI.
884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 884 class Rule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the rule. module RuleType # Not specified. RULE_TYPE_UNSPECIFIED = 0 # Baseline rules. BASELINE = 1 # Custom rules. CUSTOM = 2 end end |
#error_message ⇒ ::String
Returns The message template for rule.
884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 884 class Rule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the rule. module RuleType # Not specified. RULE_TYPE_UNSPECIFIED = 0 # Baseline rules. BASELINE = 1 # Custom rules. CUSTOM = 2 end end |
#name ⇒ ::String
Returns Rule name.
884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 884 class Rule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the rule. module RuleType # Not specified. RULE_TYPE_UNSPECIFIED = 0 # Baseline rules. BASELINE = 1 # Custom rules. CUSTOM = 2 end end |
#primary_category ⇒ ::String
Returns The primary category.
884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 884 class Rule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the rule. module RuleType # Not specified. RULE_TYPE_UNSPECIFIED = 0 # Baseline rules. BASELINE = 1 # Custom rules. CUSTOM = 2 end end |
#remediation ⇒ ::String
Returns The remediation for the rule.
884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 884 class Rule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the rule. module RuleType # Not specified. RULE_TYPE_UNSPECIFIED = 0 # Baseline rules. BASELINE = 1 # Custom rules. CUSTOM = 2 end end |
#revision_id ⇒ ::String (readonly)
Returns Output only. The version of the rule.
884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 884 class Rule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the rule. module RuleType # Not specified. RULE_TYPE_UNSPECIFIED = 0 # Baseline rules. BASELINE = 1 # Custom rules. CUSTOM = 2 end end |
#rule_type ⇒ ::Google::Cloud::WorkloadManager::V1::Rule::RuleType
Returns The type of the rule.
884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 884 class Rule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the rule. module RuleType # Not specified. RULE_TYPE_UNSPECIFIED = 0 # Baseline rules. BASELINE = 1 # Custom rules. CUSTOM = 2 end end |
#secondary_category ⇒ ::String
Returns The secondary category.
884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 884 class Rule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the rule. module RuleType # Not specified. RULE_TYPE_UNSPECIFIED = 0 # Baseline rules. BASELINE = 1 # Custom rules. CUSTOM = 2 end end |
#severity ⇒ ::String
Returns The severity of the rule.
884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 884 class Rule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the rule. module RuleType # Not specified. RULE_TYPE_UNSPECIFIED = 0 # Baseline rules. BASELINE = 1 # Custom rules. CUSTOM = 2 end end |
#tags ⇒ ::Array<::String>
Returns List of user-defined tags.
884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 884 class Rule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the rule. module RuleType # Not specified. RULE_TYPE_UNSPECIFIED = 0 # Baseline rules. BASELINE = 1 # Custom rules. CUSTOM = 2 end end |
#uri ⇒ ::String
Returns The document url for the rule.
884 885 886 887 888 889 890 891 892 893 894 895 896 897 898 899 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 884 class Rule include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # The type of the rule. module RuleType # Not specified. RULE_TYPE_UNSPECIFIED = 0 # Baseline rules. BASELINE = 1 # Custom rules. CUSTOM = 2 end end |