Class: Google::Cloud::WorkloadManager::V1::RunEvaluationRequest
- Inherits:
-
Object
- Object
- Google::Cloud::WorkloadManager::V1::RunEvaluationRequest
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/workloadmanager/v1/service.rb
Overview
Request message for the RunEvaluation RPC.
Instance Attribute Summary collapse
-
#execution ⇒ ::Google::Cloud::WorkloadManager::V1::Execution
Required.
-
#execution_id ⇒ ::String
Required.
-
#name ⇒ ::String
Required.
-
#request_id ⇒ ::String
Optional.
Instance Attribute Details
#execution ⇒ ::Google::Cloud::WorkloadManager::V1::Execution
Returns Required. The resource being created.
591 592 593 594 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 591 class RunEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#execution_id ⇒ ::String
Returns Required. ID of the execution which will be created.
591 592 593 594 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 591 class RunEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#name ⇒ ::String
Returns Required. The resource name of the Evaluation using the form:
projects/{project}/locations/{location}/evaluations/{evaluation}.
591 592 593 594 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 591 class RunEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#request_id ⇒ ::String
Returns Optional. An optional request ID to identify requests. Specify a unique request ID so that if you must retry your request, the server will know to ignore the request if it has already been completed. The server will guarantee that for at least 60 minutes since the first request.
For example, consider a situation where you make an initial request and the request times out. If you make the request again with the same request ID, the server can check if original operation with the same request ID was received, and if so, will ignore the second request. This prevents clients from accidentally creating duplicate commitments.
The request ID must be a valid UUID with the exception that zero UUID is not supported (00000000-0000-0000-0000-000000000000).
591 592 593 594 |
# File 'proto_docs/google/cloud/workloadmanager/v1/service.rb', line 591 class RunEvaluationRequest include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |